@@ -1,5 +1,5 @@
 from sklearn.metrics import classification_report
-from matplotlib import pyplot as plt
+from .plotting_tools import make_worst_samples_pie, make_fpfn_hists
 import numpy as np
 '''
 metricians are objects which take as input DataFrame 
@@ -8,28 +8,6 @@ and produce dictionary of metrics and other data describing classification resul
 for a given samples
 '''
 
-def make_worst_samples_pie(worst_samples, unite_after=15):
-    counts_series = worst_samples.value_counts(['label'])
-    labels = []
-    sizes = []
-    the_rest = 0
-    for cnt,(i,c) in enumerate(counts_series.items()):
-        if cnt < unite_after:
-            labels.append(str(i))
-            sizes.append(c)
-        else:
-            the_rest+=c
-    sizes.append(the_rest)
-    labels.append('all the rest')
-    
-    fig1, ax1 = plt.subplots()
-    ax1.pie(sizes, labels=labels, autopct='%1.1f%%',
-            shadow=True, startangle=90)
-    ax1.axis('equal')  # Equal aspect ratio ensures that pie is drawn as a circle.
-
-    return fig1
-
-
 class Metrician(object):
     '''
     Metrician providing following metrics and data from data frame:
@@ -43,14 +21,14 @@ class Metrician(object):
     def __init__(self, 
                  sort_classes_by='total_loss',
                  sort_samples_by='loss',
-                 topN=5,
                  top_percent_samples=0.1,
-                 global_metrics=['accuracy', 'weighted avg', 'macro avg']):
+                 global_metrics=['accuracy', 'weighted avg', 'macro avg'],
+                 N_fpfn_charts=10):
         self.sort_classes_by = sort_classes_by
         self.sort_samples_by = sort_samples_by
-        self.topN = topN
         self.top_percent_samples = top_percent_samples
         self.global_metrics = global_metrics
+        self.N_fpfn_charts = N_fpfn_charts
     def __call__(self, test_results, idx_name_dict=None):
         report = classification_report(test_results['label'],
                                        test_results['pred'],
@@ -93,11 +71,20 @@ class Metrician(object):
 
         worst_samples, worst_samples_piechart = \
            self.get_worst_samples(test_results, idx_name_dict=idx_name_dict)
+        #picking bar charts of top N worst classes.
+        class_wise_fpfn_bar_charts = make_fpfn_hists(test_results)
+        figures = {}
+        for i in range(self.N_fpfn_charts):
+            #ugly-ugly reverse renaming
+            key = flat_report['class_id'][i].split(' ')[0]
+            print(key, type(class_wise_fpfn_bar_charts[int(key)]))
+            if class_wise_fpfn_bar_charts[int(key)] is not None:
+               figures[key] = class_wise_fpfn_bar_charts[int(key)]
 
+        figures['Worst_samples_piechart'] = worst_samples_piechart
         metrics = {'Class-wise_report' : flat_report,
                    'Worst_samples' : worst_samples,
-                   'Figures' :
-                    {'Worst_samples_piechart' : worst_samples_piechart},
+                   'Figures' : figures,
                    'Samples_threshold' : self.top_percent_samples,
                    'Global_metrics' : global_metrics}
         return metrics
@@ -117,4 +104,5 @@ class Metrician(object):
             worst_samples['pred'] = worst_samples.apply(get_pred_name, axis=1)
             worst_samples['label'] = worst_samples.apply(get_label_name, axis=1)
         pie_chart = make_worst_samples_pie(worst_samples)
-        return worst_samples, pie_chart
\ No newline at end of file
+        return worst_samples, pie_chart
+
